@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 //! Getting the Git status of files and directories.
 
 use std::env;
@@ -382,7 +388,7 @@ fn current_branch(repo: &git2::Repository) -> Option<String> {
             if e.code() == git2::ErrorCode::UnbornBranch
                 || e.code() == git2::ErrorCode::NotFound =>
         {
-            return None
+            return None;
         }
         Err(e) => {
             error!("Error looking up Git branch: {:?}", e);
@@ -390,16 +396,7 @@ fn current_branch(repo: &git2::Repository) -> Option<String> {
         }
     };
 
-    if let Some(h) = head {
-        if let Some(s) = h.shorthand() {
-            let branch_name = s.to_owned();
-            if branch_name.len() > 10 {
-                return Some(branch_name[..8].to_string() + "..");
-            }
-            return Some(branch_name);
-        }
-    }
-    None
+    head.and_then(|h| h.shorthand().map(std::string::ToString::to_string))
 }
 
 impl f::SubdirGitRepo {
