@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 //! Parsing command-line strings into exa options.
 //!
 //! This module imports exa’s configuration types, such as `View` (the details
@@ -198,7 +204,7 @@ impl Options {
                 .is_some()
         {
             return Err(OptionsError::Unsupported(String::from(
-                "Options --git and --git-ignore can't be used because `git` feature was disabled in this build of exa"
+                "Options --git and --git-ignore can't be used because `git` feature was disabled in this build of exa",
             )));
         }
         let view = View::deduce(matches, vars)?;
